@@ -1,13 +1,15 @@
+use std::borrow::{Cow, Borrow};
 use std::cmp::Ordering;
 use std::fmt::{Debug, Formatter};
+use std::ops::Deref;
 
 use serde::{Deserializer, Serializer};
-use std::borrow::Cow;
 
 /// convert serde_json::Value to Value
 pub trait AsProxy {
     fn into_proxy(self) -> Value<'static>;
     fn as_proxy(&self) -> Value<'_>;
+    fn as_sql(&self) -> String;
 }
 
 
@@ -19,12 +21,20 @@ pub struct Value<'a> {
     pub inner: Cow<'a, serde_json::Value>,
 }
 
-impl Default for Value<'_>{
+impl Default for Value<'_> {
     fn default() -> Self {
         serde_json::Value::Null.into_proxy()
     }
 }
 
+impl<'a> Deref for Value<'a> {
+    type Target = serde_json::Value;
+
+    fn deref(&self) -> &Self::Target {
+        self.inner.as_ref()
+    }
+}
+
 impl<'a> Value<'a> {
     pub fn i64(&self) -> i64 {
         self.inner.as_i64().unwrap_or_default()
@@ -124,7 +134,7 @@ impl<'a> Value<'a> {
 }
 
 impl<'a> Value<'a> {
-    fn into_proxy(self) -> Value<'a> {
+    pub fn into_proxy(self) -> Value<'a> {
         self
     }
     pub fn as_proxy(self) -> Value<'a> {
@@ -151,6 +161,16 @@ impl AsProxy for serde_json::Value {
             inner: Cow::Borrowed(self)
         }
     }
+    fn as_sql(&self) -> String {
+        match self {
+            serde_json::Value::String(s) => {
+                return self.as_str().unwrap().to_string();
+            }
+            _ => {
+                return self.to_string();
+            }
+        }
+    }
 }
 
 impl AsProxy for &serde_json::Value {
@@ -165,6 +185,16 @@ impl AsProxy for &serde_json::Value {
             inner: Cow::Borrowed(self)
         }
     }
+    fn as_sql(&self) -> String {
+        match self {
+            serde_json::Value::String(s) => {
+                return self.as_str().unwrap().to_string();
+            }
+            _ => {
+                return self.to_string();
+            }
+        }
+    }
 }
 
 
@@ -216,11 +246,15 @@ impl AsProxy for &str {
         }
     }
 
-    fn as_proxy(&self) -> Value<'static> {
+    fn as_proxy(&self) -> Value<'_> {
         Value {
             inner: Cow::Owned(serde_json::Value::String(self.to_string()))
         }
     }
+
+    fn as_sql(&self) -> String {
+        return self.to_string();
+    }
 }
 
 macro_rules! impl_into_proxy {
@@ -232,11 +266,15 @@ macro_rules! impl_into_proxy {
             inner: Cow::Owned(serde_json::json!(self))
         }
     }
-    fn as_proxy(&self) -> Value<'static> {
+    fn as_proxy(&self) -> Value<'_> {
         Value {
             inner: Cow::Owned(serde_json::json!(self))
         }
-    }}
+    }
+    fn as_sql(&self) -> String {
+        self.to_string()
+    }
+ }
       )*
     };
 }
@@ -244,4 +282,19 @@ macro_rules! impl_into_proxy {
 impl_into_proxy!(i8 i16 i32 i64 isize);
 impl_into_proxy!(u8 u16 u32 u64 usize);
 impl_into_proxy!(f32 f64);
-impl_into_proxy!(String);
\ No newline at end of file
+impl_into_proxy!(String);
+
+impl<'a> From<&'a Value<'_>> for &'a str {
+    fn from(arg: &'a Value) -> &'a str {
+        arg.str()
+    }
+}
+
+impl<'a> From<Value<'a>> for &'a str {
+    fn from(arg: Value) -> &'a str {
+        unsafe {
+            let s = arg.str();
+            return &*(s as *const str);
+        }
+    }
+}
